@@ -7,7 +7,7 @@ use xloc::App;
 
 fn main() {
     let parser = Parser::new();
-    let app = App::new(parser.njobs);
+    let app = App::new(parser.njobs, parser.words);
 
     let total = parser
         .paths
@@ -23,3 +23,13 @@ fn main() {
 
     println!("{}", total);
 }
+
+#[cfg(test)]
+mod main_tests {
+    use super::main;
+
+    #[test]
+    fn main_test() {
+        assert_eq!(main(), ());
+    }
+}
